@@ -59,3 +59,15 @@ setMethod("determinant", signature(x = "dsCMatrix", logarithm = "logical"),
           class(val) <- "det"
           val
       })
+
+setMethod("writeHB", signature(obj = "dsCMatrix"),
+          function(obj, file, ...)
+          .Call("Matrix_writeHarwellBoeing",
+                if (obj@uplo == "U") t(obj) else obj,
+                as.character(file), "DSC"))
+
+setMethod("writeMM", signature(obj = "dsCMatrix"),
+          function(obj, file, ...)
+          .Call("Matrix_writeMatrixMarket",
+                if (obj@uplo == "U") t(obj) else obj,
+                as.character(file), "DSC"))
