@@ -11,11 +11,11 @@ setMethod("t", signature(x = "lgCMatrix"),
           valueClass = "lgCMatrix")
 
 setMethod("crossprod", signature(x = "lgCMatrix", y = "missing"),
-	  function(x, y = NULL) .Call("lgCMatrix_crossprod", x, TRUE),
+	  function(x, y = NULL) .Call("lgCMatrix_crossprod", x, TRUE, NULL),
 	  valueClass = "lsCMatrix")
 
 setMethod("tcrossprod", signature(x = "lgCMatrix"),
-	  function(x) .Call("lgCMatrix_crossprod", x, FALSE),
+	  function(x) .Call("lgCMatrix_crossprod", x, FALSE, NULL),
 	  valueClass = "lsCMatrix")
 
 setAs("lgCMatrix", "dgCMatrix",
@@ -23,3 +23,14 @@ setAs("lgCMatrix", "dgCMatrix",
                          x = rep(1, length(from@i)),
                          Dim = from@Dim, Dimnames = from@Dimnames))
 
+setAs("lgCMatrix", "lgTMatrix",
+      function(from) new("lgTMatrix", i = from@i,
+                         j = .Call("Matrix_expand_pointers", from@p),
+                         Dim = from@Dim, Dimnames = from@Dimnames))
+
+setMethod("image", "lgCMatrix",
+          function(x, ...) {
+              x <- as(as(x, "dgCMatrix"), "dgTMatrix")
+              callGeneric()
+          })
+
